@@ -225,8 +225,7 @@ class EggTranslations(object):
           @type fallback: C{boolean}
 
         """
-        assert(self._init, False,
-              "EggTranslations already initialized")
+        assert self._init == False, "EggTranslations already initialized"
 
         if type(iniFileName) == types.StringType:
             iniFileName = unicode(iniFileName,
@@ -237,9 +236,9 @@ class EggTranslations(object):
             # ASCII characters
             encoding = unicode(encoding)
 
-        assert(type(iniFileName) == types.UnicodeType)
-        assert(type(encoding) == types.UnicodeType)
-        assert(type(fallback) == types.BooleanType)
+        assert type(iniFileName) == types.UnicodeType
+        assert type(encoding) == types.UnicodeType
+        assert type(fallback) == types.BooleanType
 
         self._init = True
         self._fallback = fallback
@@ -306,7 +305,7 @@ class EggTranslations(object):
         @return: C{bool} True if the name is found otherwise False
         """
 
-        assert(self._init, True)
+        assert self._init
 
         if type(project) == types.StringType:
              project = unicode(project)
@@ -314,14 +313,14 @@ class EggTranslations(object):
         if type(name) == types.StringType:
              name = unicode(name)
 
-        assert(type(project) == types.UnicodeType)
-        assert(type(name) == types.UnicodeType)
+        assert type(project) == types.UnicodeType
+        assert type(name) == types.UnicodeType
 
         if locale is not None:
             if type(locale) == types.UnicodeType:
                 locale = str(locale)
 
-            assert(type(locale) == types.StringType)
+            assert type(locale) == types.StringType
             return (project, name, locale) in self._iniCache
 
         if not self._fallback:
@@ -1015,7 +1014,7 @@ class EggTranslations(object):
                  or the default value in args if no
                  localization found.
         """
-        assert(self._init, True)
+        assert self._init
 
         if type(project) == types.StringType:
              project = unicode(project)
@@ -1026,9 +1025,9 @@ class EggTranslations(object):
         if type(txt) == types.StringType:
              txt  = unicode(txt)
 
-        assert(type(project) == types.UnicodeType)
-        assert(type(name) == types.UnicodeType)
-        assert(type(txt) == types.UnicodeType)
+        assert type(project) == types.UnicodeType
+        assert type(name) == types.UnicodeType
+        assert type(txt) == types.UnicodeType
 
         if self._fallback:
             for locale in self._localeSet:
@@ -1059,7 +1058,7 @@ class EggTranslations(object):
                  in initialize or setLocaleSet methods
                  otherwise False.
         """
-        assert(self._init, True)
+        assert self._init
         return self._fallback
 
     def hasTranslation(self, project, name, locale):
@@ -1100,7 +1099,7 @@ class EggTranslations(object):
                   project, name, and locale otherwise False.
         """
 
-        assert(self._init, True)
+        assert self._init
 
         try:
             return self._moCache[(project, name)].has_key(locale)
@@ -1127,7 +1126,7 @@ class EggTranslations(object):
         @return: C{list} of C{str} locale language / country codes.
         """
 
-        assert(self._init, True)
+        assert self._init
 
         try:
             return self._localeCache[project]
@@ -1146,7 +1145,7 @@ class EggTranslations(object):
         @return: C{unicode} the name of the resource ini file.
         """
 
-        assert(self._init, True)
+        assert self._init
         return self._iniFileName
 
     def getLocaleSet(self):
@@ -1157,7 +1156,7 @@ class EggTranslations(object):
         @return: C{list} of C{str} locale language / country codes.
         """
 
-        assert(self._init, True)
+        assert self._init
         return self._localeSet
 
     def setLocaleSet(self, localeSet, fallback=True):
@@ -1206,7 +1205,7 @@ class EggTranslations(object):
           @type fallback: C{boolean}
         """
 
-        assert(self._init, True)
+        assert self._init
 
         self._fallback = fallback
 
@@ -1218,7 +1217,7 @@ class EggTranslations(object):
                     tmpLocaleSet[i] = str(tmpLocaleSet[i])
 
                 # All entries in the locale set must be strings
-                assert(type(tmpLocaleSet[i]) == types.StringType)
+                assert type(tmpLocaleSet[i]) == types.StringType
 
 
         elif type(localeSet) == types.StringType:
@@ -1329,7 +1328,7 @@ class EggTranslations(object):
                    locale.
         """
     
-        assert(type(locale) == types.StringType)
+        assert type(locale) == types.StringType
         
         components = locale.split("_")
         
@@ -1355,7 +1354,7 @@ class EggTranslations(object):
                    otherwise False
     
         """
-        assert(type(locale) == types.StringType)
+        assert type(locale) == types.StringType
     
         size = len(locale)
     
@@ -1383,7 +1382,7 @@ class EggTranslations(object):
                    and lang code fallbacks.
         """
     
-        assert(type(localeSet) == types.ListType)
+        assert type(localeSet) == types.ListType
     
         for locale in localeSet:
                 yield locale
@@ -1756,7 +1755,7 @@ class EggTranslations(object):
 
 
     def _getTupleForKey(self, project, name, locale=None):
-        assert(self._init, True)
+        assert self._init
 
         if type(project) == types.StringType:
              project = unicode(project)
@@ -1765,8 +1764,8 @@ class EggTranslations(object):
              name = unicode(name)
 
 
-        assert(type(project) == types.UnicodeType)
-        assert(type(name) == types.UnicodeType)
+        assert type(project) == types.UnicodeType
+        assert type(name) == types.UnicodeType
 
         if locale is None and not self._fallback:
             locale = self._localeSet[0]
@@ -1775,7 +1774,7 @@ class EggTranslations(object):
             if type(locale) == types.UnicodeType:
                 locale = str(locale)
 
-            assert(type(locale) == types.StringType)
+            assert type(locale) == types.StringType
             key = (project, name, locale)
 
             if key in self._iniCache:
@@ -1824,7 +1823,7 @@ def stripCountryCode(locale):
 
       @return: C{str} with country code removed
     """
-    assert(type(locale) == types.StringType)
+    assert type(locale) == types.StringType
 
     return (locale.split('_')[0]).lower()
 
@@ -1841,7 +1840,7 @@ def hasCountryCode(locale):
                otherwise False
     """
 
-    assert(type(locale) == types.StringType)
+    assert type(locale) == types.StringType
 
     return len(locale) == 5 and locale[2] == '_'
 
@@ -1869,7 +1868,7 @@ def stripEncodingCode(locale):
         stripping was required.
     """
 
-    assert(type(locale) == types.StringType)
+    assert type(locale) == types.StringType
 
     dot = locale.find(".")
     if dot != -1:
